@@ -9,8 +9,7 @@ use Data::Page;
 use Teng::Plugin::SearchBySQLAbstractMore ();
 
 our @EXPORT = qw/search_by_sql_abstract_more_with_pager/;
-our $VERSION = '0.05';
-
+our $VERSION = '0.06';
 sub init {
     $_[1]->Teng::Plugin::SearchBySQLAbstractMore::_init();
 }
@@ -28,10 +27,15 @@ sub search_by_sql_abstract_more_with_pager {
     my $table = $self->schema->get_table($table_name) or Carp::croak("No such table $table_name");
     my ($sql, @binds) = $sql_abstract_more->select(%$args);
 
-    $args->{-columns} = [ 'count(*)' ];
-    delete @{$args}{qw/-offset -limit/};
+    delete @{$args}{qw/-offset -limit -order_by/};
 
+    if (not $args->{-having} and not $args->{-group_by}) {
+        $args->{-columns} = ['count(*)'];
+    }
     my ($count_sql, @count_binds) = $sql_abstract_more->select(%$args);
+    if ($args->{-having} or $args->{-group_by}) {
+        $count_sql = "SELECT COUNT(*) as cnt FROM ($count_sql) AS total_count";
+    }
     my $count_sth = $self->dbh->prepare($count_sql) or Carp::croak $self->dbh->errstr;
     my $sth       = $self->dbh->prepare($sql)       or Carp::croak $self->dbh->errstr;
     my ($total_entries, $itr);
